#
# spec file for package lutris
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         _py 311
%define         _pyb 3.11
%define         appid net.lutris.Lutris
%{?sle15_python_module_pythons}
Name:           lutris
Version:        0.5.19
Release:        2.2
Summary:        Manager for game installation and execution
License:        GPL-3.0-or-later
URL:            https://lutris.net
Source0:        https://github.com/lutris/lutris/archive/refs/tags/v%{version}.tar.gz
Source1:        %{name}.apparmor
Requires:       xrandr
# boo#1213440
Recommends:     ca-certificates-steamtricks
Recommends:     winetricks
BuildArch:      noarch
%if 0%{?suse_version} >= 1600
BuildRequires:  apparmor-abstractions
BuildRequires:  apparmor-rpm-macros
BuildRequires:  fdupes
BuildRequires:  gettext-tools
BuildRequires:  gobject-introspection
BuildRequires:  hicolor-icon-theme
BuildRequires:  libapparmor-devel
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  python3-devel >= 3.7
BuildRequires:  python3-gobject
BuildRequires:  python3-setuptools
Requires:       cabextract
Requires:       curl
Requires:       fluid-soundfont-gm
Requires:       p7zip
Requires:       psmisc
Requires:       python3-Pillow
Requires:       python3-PyYAML
Requires:       python3-certifi
Requires:       python3-dbus-python
Requires:       python3-distro
# controller support
Requires:       python3-evdev
Requires:       python3-gobject
Requires:       python3-gobject-Gdk
Requires:       python3-lxml
Requires:       python3-protobuf
Requires:       python3-requests
%if %{with discord}
Requires:       python3-pypresence
%endif
%if %{with moddb}
Requires:       python3-moddb
%endif
%else
BuildRequires:  apparmor-abstractions
BuildRequires:  apparmor-rpm-macros
BuildRequires:  fdupes
BuildRequires:  gettext-tools
BuildRequires:  gobject-introspection
BuildRequires:  hicolor-icon-theme
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  python%{_py}-devel
BuildRequires:  python%{_py}-gobject
BuildRequires:  python%{_py}-setuptools
Requires:       cabextract
Requires:       curl
Requires:       fluid-soundfont-gm
Requires:       p7zip
Requires:       psmisc
Requires:       python%{_py}-Pillow
Requires:       python%{_py}-PyYAML
Requires:       python%{_py}-certifi
Requires:       python%{_py}-dbus-python
Requires:       python%{_py}-distro
Requires:       python%{_py}-lxml
Requires:       python%{_py}-protobuf
Requires:       python%{_py}-requests
# controller support
# we can't have controller support in Leap as python311-evdev is missing
%if %{with discord}
Requires:       python%{_py}-pypresence
%endif
%if %{with moddb}
Requires:       python%{_py}-moddb
%endif
%endif

%lang_package

%description
Lutris allows to gather and manage (install, configure and launch)
all games acquired from any source, in a single interface.
This includes, for example, Steam or GOG games, Windows games (WINE),
or emulated console games and browser games.

%package apparmor
Summary:        Apparmor profile for %{name}
Requires:       %{name} = %{version}-%{release}
Supplements:    (%{name} and apparmor-profiles)

%description apparmor
%{summary}.

%prep
%autosetup

%build
%if 0%{?suse_version} >= 1600
%meson
%meson_build
%else
%python_build
%endif

%install
%if 0%{?suse_version} >= 1600
%meson_install
%find_lang %{name}
%python3_fix_shebang_path %{buildroot}%{_bindir}/*
%python3_fix_shebang_path %{buildroot}%{_datadir}/%{name}/bin/*
%else
%python_install
sed -i "s|!%{_bindir}/env python3|!%{_bindir}/python%{_pyb}|" \
     %{buildroot}%{_datadir}/%{name}/bin/%{name}-wrapper
%endif
%fdupes %{buildroot}

#install apparmor profile
install -d %{buildroot}%{_sysconfdir}/apparmor.d
install -Dm0644 %{SOURCE1} %{buildroot}%{_sysconfdir}/apparmor.d/usr.bin.%{name}

%files
%doc README.rst CONTRIBUTING.md AUTHORS
%license LICENSE
%{_bindir}/%{name}
%{_mandir}/man?/%{name}.?%{?ext_man}
%{_datadir}/%{name}
%{_datadir}/applications/%{appid}.desktop
%{_datadir}/icons/hicolor/scalable/apps/%{appid}.svg
%{_datadir}/icons/hicolor/??x??/apps/%{appid}.png
%{_datadir}/icons/hicolor/???x???/apps/%{appid}.png
%{python_sitelib}/%{name}
%{_datadir}/metainfo/%{appid}.metainfo.xml

%if 0%{?suse_version} >= 1600
%files lang -f %{name}.lang
%else
%{python_sitelib}/%{name}-*.egg-info
%endif

%files apparmor
%{_sysconfdir}/apparmor.d/usr.bin.%{name}

%changelog
* Fri Feb 28 2025 Dirk Stoecker <opensuse@dstoecker.de>
- Fix wrong placement of lang_package macro in spec file
* Mon Feb 24 2025 Michael Vetter <mvetter@suse.com>
- Update to 0.5.19:
  * Fix Proton integration bugs so Proton-fixes are applied
  * Do not offer DXVK, VKD3D, D3D Extras or DDXVK-NVAPI on Proton versions;
    Proton will handle these.
  * The "Enable Esync" and "Enable Fsync" settings are now passed on to Proton
  * DXVK's integrated D8VK will be enabled in Proton
  * Emulator BIOS file location (used by libretro) may be set in Preferences
  * Obtain the release year from GOG and Itch.io.
  * MAME Machine setting uses a searchable entry for its enourmous list
  * Support for importing Commodore 64 ROMs
* Mon Dec 16 2024 Carsten Ziepke <kieltux@gmail.com>
- Add BuildRequires apparmor-abstractions, apparmor-rpm-macros for
  Leap, fix for build error: directories not owned by a package:
  /etc/apparmor.d
* Mon Dec  2 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 0.5.18:
  * Lutris downloads the latest GE-Proton build for Wine if any Wine version is installed
  * Use dark theme by default
  * Display cover-art rather than banners by default
  * Add 'Uncategorized' view to sidebar
  * Preference options that do not work on Wayland will be hidden when on Wayland
  * Game searches can now use fancy tags like 'installed:yes' or 'source:gog', with explanatory tool-tip
  * A new filter button on the search box can build many of these fancy tags for you
  * Runner searches can use 'installed:yes' as well, but no other fancy searches or anything
  * Updated the Flathub and Amazon source to new APIs, restoring integration
  * Itch.io source integration will load a collection named 'Lutris' if present
  * GOG and Itch.io sources can now offer Linux and Windows installers for the same game
  * Added support for the 'foot' terminal
  * Support for DirectX 8 in DXVK v2.4
  * Support for Ayatana Application Indicators
  * Additional options for Ruffle runner
  * Updated download links for the Atari800 and MicroM8 runners
  * No longer re-download cached installation files even when some are missing
  * Lutris log is included in the 'System' tab of the Preferences window
  * Improved error reporting, with the Lutris log included in the error details
  * Add AppArmor profile for Ubuntu versions >= 23.10
  * Add Duckstation runner
- add apparmor profile in it's seperate package
- remove BR update-desktop-files
* Sat May  4 2024 Richard Rahl <rrahl0@disroot.org>
- switch to meson, so we can have translations
- fixing packaging issues with Leap 15.6 (old packaging had Requires
  which were not in Leap)
- remove packaging for Leap < 1330
* Thu Apr 11 2024 Marcus Rueckert <mrueckert@suse.de>
- sync the requires with the setup.py and prepare at least the
  requires for moddb and distro support
* Thu Apr 11 2024 Marcus Rueckert <mrueckert@suse.de>
- Update to 0.5.17:
  - Fix critical bug preventing completion of installs if the
    script specifies a wine version
  - Fix critical bug preventing Steam library sync
  - Fix critical bug preventing game or runner uninstall in Flatpak
  - Support for library sync to lutris.net, this allows to sync
    games, play time and categories to multiple devices.
  - Remove "Lutris" service view; with library sync the "Games"
    view replaces it.
  - Torturous and sadistic options for multi-GPUs that were half
    broken and understood by no one have been replaced by a simple
    GPU selector.
  - EXPERIMENTAL support for umu, which allows running games with
    Proton and Vessel. Using Proton in Lutris without umu is no
    longer possible.
  - Better and sensible sorting for games (sorting by playtime or
    last played no longer needs to be reversed)
  - Support the "Categories" command when you select multiple games
  - Notification bar when your Lutris is no longer supported
  - Improved error dialog.
  - Add Vita3k runner (thanks @ItsAllAboutTheCode)
  - Add Supermodel runner
  - WUA files are now supported in Cemu
  - "Show Hidden Games" now displays the hidden games in a separate
    view, and re-hides them as soon as you leave it.
  - Support transparent PNG files for custom banner and cover-art
  - Images are now downloaded for manually added games.
  - Deprecate 'exe', 'main_file' or 'iso' placed at the root of the
    script, all lutris.net installers have been updated
    accordingly.
  - Deprecate libstrangle and xgamma support.
  - Deprecate DXVK state cache feature (it was never used and is no
    longer relevant to DXVK 2)
* Tue Jan 16 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.5.16:
  * Fix bug that prevented installers to complete
  * Better handling of Steam configurations for the Steam account picker
  * Load game library in a background thread
* Sat Jan 13 2024 Richard Rahl <rrahl0@proton.me>
- Update to 0.5.15:
  * Fix some crashes happening when using Wayland and a high
    DPI gaming mouse
  * Fix crash when opening the system preferences tab for a game
  * Reduced the locales list to a predefined one
  * Fix Lutris not expanding "~" in paths
  * Download runtime components from the main window
  * Add the ability to open a location in your file browser
    from file picker widgets
  * Add the ability to select, remove, or stop multiple games
    in the Lutris window
  * Redesigned 'Uninstall Game' dialog
  * Fix the export / import feature
  * Show an animation when a game is launched
  * Add the ability to disable Wine auto-updates
  * Add playtime editing in the game preferences
  * Move game files, runners to the trash instead of deleting
  * Add "Updates" tab in Preferences control
  * Add "Storage" tab in Preferences
  * Expand "System" tab in Preferences with more system information
  * Add "Run Task Manager" command for Wine games
  * Add two new, smaller banner sizes for itch.io games.
  * Ignore Wine virtual desktop setting when using Wine-GE/Proton
  * Ignore MangoHUD setting when launching Steam
  * Sync Steam playtimes with the Lutris library
* Fri Oct 20 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.5.14:
  * Add Steam account switcher to handle multiple Steam accounts
    on the same device.
  * Add user defined tags / categories
  * Group every API calls for runtime updates in a single one
  * Download appropriate DXVK and VKD3D versions based on
    the available GPU PCI IDs
  * EA App integration. Your Origin games and saves can be manually imported
    from your Origin prefix.
  * Add integration with ScummVM local library
  * Download Wine-GE updates when Lutris starts
  * Group GOG and Amazon download in a single progress bar
  * Fix blank login window on online services such as GOG or EGS
  * Add a sort name field
  * Yuzu and xemu now use an AppImage
  * Experimental support for Flatpak provided runners
  * Header-bar search for configuration options
  * Support for Gamescope 3.12
  * Missing games show an additional badge
  * Add missing dependency on python3-gi-cairo for Debian packages
* Wed Aug  2 2023 Michael Vetter <mvetter@suse.com>
- boo#1213440: Add recommends for ca-certificates-steamtricks
* Wed Jul 12 2023 ecsos <ecsos@opensuse.org>
- Let package also build for Leap
  - add %%{?sle15_python_module_pythons}
  - make some other adjustments so we can build for Leap
* Wed May 17 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.5.13:
  * Add support for Proton
  * Add drag and drop on the main window. Dropped files will be matched
    No-Intro, Redump and TOSEC checksums.
  * Add support for ModDB links in installers (moddb python module required)
  * Added "Missing" sidebar option for games whose directory is missing
  * Re-style the configuration, preferences, installer and add-games windows
  * Group configuration options into sections
  * Added checkbox to stop asking for the launch config for a game
  * Added checkbox to sort installed games first
  * Support for launch-configs in shortcuts and the command line
  * Show platform badges on banners and cover-art
  * Installing games from setup files can now use different presets (Win98, 3DFX, ...)
  * Add filter field to runner list
  * Show game count in search bar
  * Workaround Humble Bundle authentication issues by allowing importing
    cookies from Firefox
  * Add Itch.io integration
  * Add Battle.net integration (protobuf dependency required)
  * Improve detection of DOSBox games on GOG
  * Added "Unspecified" Vulkan ICD option
  * Removed ResidualVM (now merged into ScummVM)
  * Detect obsolete Vulkan drivers and default to DXVK 1.x for them
  * Improved High-DPI support for custom media
  * Performance improvements
- Drop fix-float-str-concat.patch
* Sun Apr 30 2023 Marcus Rueckert <mrueckert@suse.de>
- switch to autosetup
* Sun Apr 30 2023 Marcus Rueckert <mrueckert@suse.de>
- Added fix-float-str-concat.patch:
  This fixes a code error when an game crashes
  https://github.com/lutris/lutris/issues/4289
  This patch can be removed with 0.5.13
* Wed Jan 11 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Do not require python3-magic: lutris has its own, intree version
  of magic.py.
* Fri Dec  2 2022 Michael Vetter <mvetter@suse.com>
- Update to 0.5.12:
  * Add support for Xbox games with the xemu runner
  * Fix authentication issue with Origin
  * Fix authentication issue with EGS
  * Fix authentication issue with Ubisoft Connect when 2FA is enabled
  * Fix integration issue with GOG
  * Add Discord Rich Presence integration
  * Add ability to extract icons from Windows executables
  * Allow setting custom cover art
  * Re-style configuration dialogs
* Tue Sep  6 2022 Kostadin Shishmanov <kocelfc@tutanota.com>
- Remove unneeded line in the spec file which makes lutris
  appear in the "Internet" subcategory instead of "Games" in
  the KDE application launcher
* Thu Aug 25 2022 Aaron Stern <ukbeast89@protonmail.com>
- Update to 0.5.11:
  * Fix for some installers commands exiting with return code 256
  * Change shortcut for show/hide installed games to Ctrl + i
  * Show/hide hidden games is assigned to Ctrl + h
  * Install game launcher before login for services that use one.
  * Add Amazon Games integration
  * Added SheepShaver, BasiliskII and Mini vMac runners
  * Don't perform runtime updates when a game is launched via a shortcut
  * Support variables in script URLs
  * Fix crash when Lutris is unable to read the screen resolution
  * Enable Gamescope on Nvidia >= 515
  * Fixes for Steam shortcuts
  * Add Gnome Console and Deepin Terminal to supported terminal emulators
  * Fix crash when Mangohud is used alongside Gamescope
  * Translation updates
* Wed Apr 20 2022 Michael Vetter <mvetter@suse.com>
- Update to 0.5.10.1:
  * Check for Steam executable in home folder for Flatpak
  * Adjust the Steam, application and desktop shortcuts to launch with
    Flatpak when necessary
  * Disable local (XDG) service in Flatpak
  * Simplify MangoHUD option (now an On/Off toggle)
  * Remove ability for Lutris to quit Steam
  * Don't default to fsync on older kernels
  * Default to a base resolution when Lutris is unable to read the current
    configuration
  * Fix issue with .NET 4.8 installation which affects the FF XIV launcher
* Wed Apr 13 2022 Dirk Stoecker <opensuse@dstoecker.de>
- Specify minimum python version
* Mon Apr  4 2022 Michael Vetter <mvetter@suse.com>
- Update to 0.5.10:
  * Add new window to add games to Lutris, with searches from the website,
    scanning a folder for previously installed games, installing a Windows
    game from a setup file, installing from a YAML script or configuring a
    single game manually.
  * Move the search for Lutris installers from a tab in the Lutris service
    to the window for adding games.
  * Add option to add a Lutris game to Steam
  * Add a coverart format
  * Add integration with EA Origin
  * Add integration with Ubisoft Connect
  * Download missing media on startup
  * Remove Winesteam runner (install Steam for Windows in Lutris instead)
    PC (Linux and Windows) games have their own dedicated Nvidia shader cache
  * Add dgvoodoo2 option
  * Add option to enable BattleEye anti-cheat support
  * Default to Retroarch cores in ~/.config/retroarch/cores if available
  * Add support for downloading patches and DLC for GOG games
  * Add --export and --import command line flags to export a game a lutris
    game and re-import it (requires --dest for the destination path, feature still experimental)
  * Add command line flags to manage runners: --install-runner, --uninstall-runners,
  - -list-runners, --list-wine-versions
  * Change behavior of the "Stop" button, remove "Kill all Wine processes" action
  * Gamescope option is now disabled on Nvidia GPUs
  * Enable F-Sync by default
  * For details see: https://github.com/lutris/lutris/releases/tag/v0.5.10
* Mon Dec 13 2021 Tejas Guruswamy <tejas.guruswamy@opensuse.org>
- Lutris GUI requires python3-dbus-python
* Sun Oct 17 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.5.9.1:
  * Fix possible escaping error for gamescope option
  * Remove walrus operator to restore compatibility with
    Python 3.7 / Ubuntu 18.04
  * Remove log file being written in the home folder
  * Fix install button for community installer
  * Fix markup error on gamescope option
  * Update URL for Ryujinx build
  * Fix Steam sync creating duplicate games
* Wed Oct 13 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.5.9:
  * Add initial support for Epic Games Store
  * Add support for Steam for Windows as a game source
  * Add support for DXVK-NVAPI and DLSS
  * Add FidelityFX Super Resolution (FSR) option for compatible Wine versions
  * Add workaround for locale issues when Lutris is launched from Steam
  * Add gamescope option
  * Lutris games can now be launched from Steam
  * 3rd party services can be enabled or disabled in the preferences
  * The main preferences window has now tabs on the left side
  * Runner configuration is now available from the main preferences window
  * VKD3D is a separate option from DXVK
  * Esync is enabled by default
  * Dolphin is available as a game source (reads games from the emulator's
    local database of games)
  * Scan for installed games when using Steam source
  * Improved automatic installers for GOG, detection of DOSBOX and ScummVM
    games.
  * DRM free services (Humble, GOG) can locate existing installations of games
  * Use 7zip as the default extractor when not given an archive type
  * Improve process monitoring, allowing for monitoring of Steam games
  * Disable AMD switchable graphics layer by default (breaks games)
  * Removed support for Gallium 9
  * Removed support for X360CE
  * Removed legacy WineD3D options
* Wed Jul 21 2021 andy great <andythe_great@pm.me>
- Add python-magic make Lutris able to find games.
* Mon Jul  5 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.5.8.4:
  * Fix Steam icon showing too big on some systems
  * Fix DXVK not updating
  * Fix Python 3.9 compatibility
  * Update sidebar on service login
  * Remember position of window except on Wayland maybe
  * GST plugin path is now only set if it exists
  * Default to 7zip when not given an archive extractor
  * Switch IRC to Libera chat
  * Fix libretro info file loading
  * Let pipewire users toggle "Reduce PulseAudio latency"
* Mon Jan 25 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.5.8.3:
  * Really fix popovers not showing on Wayland without making
    them non-modal
  * Prevent GStreamer based configuration from being applied
    in incompatible wine builds.
  * Fix crash when wine runner accesses DXVK versions before
    they are uploaded.
  * Prevent init dialog from being closed while it
    downloads the runtime.
* Sat Jan  9 2021 Matthias Bach <marix@marix.org>
- Add recommendation to python3-distro to avoid warning on startup.
* Fri Jan  8 2021 Caleb McKay <caleb@candj.us>
- Added additional dependencies required by Lutris to run.
  * python3-lxml
  * python3-cssselect
* Wed Jan  6 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.5.8.2:
  * Fix popover menus not appearing on Wayland
  * Fix game bar getting unselected on Wayland (Forces the last game to stay
    selected)
  * Update Chinese, Dutch, German and Russian translations
  * Download DXVK when Lutris starts
  * Add fsync2 feature detection
  * Limit simultaneous downloads to 3
  * Add support for deb file extraction
  * Add support for Adobe Air games from Humble Bundle (Installation only,
  * Air runtime will come at a later stage)
  * Add support for GStreamer enabled Wine builds. This will provide better
    compatibility for games using Media Foundation
* Mon Nov 30 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.5.8.1:
  * Remove Proton from available Wine versions
  * Display a dialog until Lutris finishes initializing
  * Allow to keep game files when uninstalling a game
  * Remove custom sidebar CSS
  * Fix popup menu not showing in list view
  * Fix script loading for local files
  * Fix installed at column setting name for list view
  * Fix lutris not launching games with rungameid
  * Fix installed Steam game for fresh lutris installs
* Mon Nov 16 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.5.8:
  * 3rd party services are now available from the main window
  * The "Import games" window has been removed. The concept of
    importing games from other services into Lutris has been removed.
  * Syncing games from other services on start has been removed.
  * Integration with the lutris website such as login and showing your
    library has been delegated to the 'lutris' service in the sidebar.
  * The lutris service gives the option of searching your library or the whole
    lutris.net library.
  * Games from 3rd party services no longer depend on an install script to be
    present on the website. Lutris will automatically install games with an
    auto-generated script. Scripts from the website take precedence if available.
  * Steam games are directly loaded from the Steam API and it is no longer needed
    to sync your Steam library on the lutris website to see all your Steam games.
  * Game banners and icons are downloaded from the services themselves. This
    allows for customized media size in the UI based on what's available from the
    service.
  * Added option to hide the text under the icons
  * The installer game cache configuration has been moved to the installer
    window.
  * Installers now offer the choice between downloaded files, custom user
    provided files or cached files (when available).
  * Bonus content for GOG games such as manuals or soundtracks can now be
    downloaded as part of the install process. Selected content are downloaded
    in a 'extras' folder in the game folder. Those files will likely be in
    compressed format.
  * The right side bar has been moved to the bottom of the window to optimize
    space and to declutter the overall design. Game actions are now shown in a
    popover menu displayed next to the play button. Runner actions, if available
    (for example, wine), will show up in a popover menu next to the runner icon.
  * Running games have been moved from the right side bar to a row on the left
    side bar.
  * Added favorites section and allow to add/remove games from favorites
    When removing a game, Lutris now displays the size of the folder to be
    deleted.
  * Game logs are no longer erased when switching to another game in the
    window.
  * Game logs can be saved to a file
  * Lutris runners can now be written in JSON instead of Python code. This
    handles only simple cases but it's enough to handle a vast number of
    emulators or game engines. Some existing runners have been migrated to JSON
    such as dgen, ppsspp, citra, ags, virtualjaguar... as well as new ones like
    melonds, tic80, pcem... Check out the share/lutris/json folder for those
    runners. If you plan to submit new JSON based runner be sure to provide a valid
    'download_url' otherwise the lutris client won't have a runner to download.
  * Lutris will not delete any game folder that is used by another game or any
    folder that is in some predefined locations. Note that protection of folders
    such as 'Documents' or 'Downloads' only works on English locales for the moment.
  * Added a Mangohud option with special modes for OpenGL and 32bit games.
  * Added a wine menu entry to launch a bash shell in the game's environment
    with WINEPREFIX set and the correct Wine build aliased to wine.
  * Added a command line option to generate a bash script that will run a
    lutris game without the client. ex: lutris quake --output-script quake.sh.
    This will create a 'quake.sh' script to launch the game.
  * Removed all platform and runner icons from the code base to eliminate any
    issue regarding their licenses (This is done to help get the lutris
    package into debian).
  * DOSBox and PCSX2 display an error if needed libraries are missing.
  * The old versions of gamemode are no longer supported. Make sure you have
    the one that ships with a gamemoderun executable.
  * The runtime now supports downloading individual files. New icons can be
    submitted by sending a PR to github.com/lutris/lutris-runtime.
  * Refactor of several core components. New python packages
    lutris.database and lutris.gui.installer
* Mon Jul 20 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.5.7.1:
  * Provide D3D12.DLL, based on vkd3d3-proton project
  (https://github.com/HansKristian-Work/vkd3d-proton),
  as part of our DXVK runtime. This will help push updates faster
  and provide better compatibility for Direct3D 12 titles such as
  World of Warcraft.
* Sun Jul  5 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.5.7:
  * Use Meson and Ninja to build translation files
  * Improve Debian package compliance with standards
  * Add translation strings for the code base
  * Set a default directory to manually added games,
    allowing to remove them
  * Deprecate MESS runner
  * Migrate all MESS games to MAME
  * Get full supported system list from the XML given by MAME
  * Allow to run MAME games by ID if the ROM path is set
  * Add a no-GUI option to RPCS3
  * Fix GalliumNine conflicts with DXVK
  * Improve performance of DirectX 12 games running on AMD GPU by
    setting RADV_DEBUG=zerovram
  * Code style fixes. Pylint is now used in the Travis checks.
* Wed Apr 15 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.5.6:
  * Add some wine core processes to be excluded from monitor (Fixes Battle.net
    and Origin installation issues)
  * Convert play time from string to float in the database. Do not downgrade
    back to older versions or you'll experience issues.
  * Fix for the wine sandbox on non English systems
  * Allow Citra and MAME to be launched as standalone programs
  * Avoid a crash if ldconfig -p returns corrupt data
  * Allow custom messages to be displayed at the end of install scripts
  * Add option to provide alternate config file for PCSX2 games
  * Fix issue with usernames containing accented characters
  * Fix "Restrict to display" option on Wayland/Mutter
  * Fix blurry icons on KDE
  * Remove broken translation files (until internationalization is done properly)
  * Switch source of DXVK builds to Lutris' own (allows Lutris to delay broken
    DXVK releases and ship custom ones)
* Mon Mar 30 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.5.5:
  * Initial support for Humble Bundle
  * Add resolution switching support for Wayland (Mutter only)
  * Add option to enable ACO shader compiler on Mesa >= 19.3
  * DXVK is enabled by default
  * Add initial support for VKD3D
  * Migrate D9VK configs to use DXVK
  * Remove d3d10 and d3d10_1 from dlls handled by DXVK
  * Fix an API breakage occuring with a Gtk update
  * Add a System info tab in Preferences
  * Better handle authentication failure for GOG
  * Fix case issue with key lookup in Steam VDF files
  * Add Yuzu runner
  * Add bsnes-hd beta and smsplus libretro cores
  * Add sound device option for Mednafen
  * Remove bundled winetricks
  * Remove xboxdrv integration
- Remove lutris-0.5.4-boo1161650-remove-polkit.patch: upstreamed
- Remove lutris-0.5.4-sort_new_with_model_fix.patch: upstreamed
* Mon Mar  2 2020 Jacob W <jacob@jacobwinski.com>
- Add lutris-0.5.4-sort_new_with_model_fix.patch adding support for renamed gtk attribute, fixing lutris crashing on startup.
* Thu Feb  6 2020 Michael Vetter <mvetter@suse.com>
- boo#1161650: Add lutris-0.5.4-boo1161650-remove-polkit.patch
  Backport upstream commits:
  * 6f6b50cf66e676bbe05605e9813f0a034a35bb81
  * 7d73c5a985fde5ffadf83e83d836d9c582ed25d3
  * f2f8a0481fc2bb12d754ea6806140ed94d219288
  to remove xboxdrv and thus don't need polkit any longer.
* Wed Feb  5 2020 Michael Vetter <mvetter@suse.com>
- boo#1161650:
  Remove lutris.rpmlintrc and BuildIgnore line.
  We want the polkit-unauthorized-privilege error to show.
  Security team will add whitelisting.
* Wed Dec 18 2019 ecsos@opensuse.org
- Add some missing dependencies:
  curl, p7zip, psmisc, xrandr
* Thu Nov 28 2019 Michael Vetter <mvetter@suse.com>
- Update to 0.5.4:
  * Added support for Python 3.8.
  * Added config validation.
  * Added support for Nvidia PRIME off-load.
  * Added a popup after a successful game import.
  * Added alacritty as a terminal option.
  * Newly installed games that don't specify wine version will now default to the version used during installation.
  * Provide a fallback for when Lutris can't create a working directory.
  * Update libretro runners list.
  * Removed runners that have no binary builds.
  * Esync can now be enabled for Wine Staging >= 4.6.
  * Default scaling option for Mednafen is now nn4x.
  * steamwebhelper.exe is no longer disabled to avoid issues with the new Steam UI.
  * Ignore special symbols when generating identifiers for games.
  * Wine processes are now killed if installation is cancelled.
  * Fixed installation issues for users whose username begin with "x".
  * Fixed a bug with side panels hidden by default on first start.
  * Fixed an issue that would not allow user to unselect a game in right panel by clicking on an empty space in the library if that game was no longer installed.
  * Fixed an issue that allowed user to change the configuration of a game that was already removed.
  * Fixed an issue that made games imported from native Steam to appear as uninstalled.
  * Fixed a bug that opened Wine Console instead of Wine Registry.
  * Fixed warnings that occurred when Gamemode was enabled.
  * Fixed various locale issues.
  * Fixed a bug preventing Lutris to find Gallium Nine libraries.
  * Fixed issues with positioning of the Lutris window.
  * Fixed game panel updates on game quit.
  * Fixed game loading error in cases when libstrangle is missing but was previously enabled.
  * Fixed a bug that made Lutris download Linux version of a GOG game even when the runner was set to Wine.
  * Fixed installation of the local install scripts.
  * Fixed installation issues for wine installers that don't have a "files" section.
  * Further fixed issues with wine sandboxing on non-english systems.
* Mon Sep  9 2019 mvetter@suse.com
- Update to 0.5.3:
  * Added D9VK option.
  * Added options to hide right and left panels.
  * Added support for Discord Rich Presence (option is only available if you
    have python-pypresence installed).
  * Added option to launch Wine console.
  * Added option to hide Lutris on game launch.
  * Added lazy loading for some UI components that fetch data from Lutris.
  * WINE_LARGE_ADDRESS_AWARE is now set to 1 when DXVK or D9VK is enabled
    (only works with lutris-provided builds) to workaround crashes in 32-bit games.
  * Lutris should now be minimized when launching games from shortcuts.
  * An error is now displayed when Lutris fails to install a runner.
  * Added Ubuntu's AMDVLK path to Vulkan ICD loader search.
  * State of right panel is now refreshed after adding/removing shortcuts.
  * Working directory no longer defaults to /tmp
  * Switched PC-Engine module from pce to pce_fast.
  * Fixed crash due to invalid GOG credentials.
  * Fixed UI bug that would sometimes result in “No File Provided” error messages.
  * Fixed bug that would lead to path warnings when prompted to select files.
  * Fixed crashes due to unexpected data from xrandr.
  * Fixed bug that could make antialiasing not function in some games.
  * Fixed sorting for games that start with a lowercase letter.
  * Fixed bug that would cause user session to end when launching games on Linux Mint.
  * Fixed bug with process monitor that could cause games to not launch.
  * Fixed bug that would not let user execute some options and launch external
    executables when a game is still running and ESYNC is enabled.
  * Fixed issues with restoration of original .dll files when disabling DXVK/D9VK.
  * Fixed crashes due to inability to read GPU driver information.
  * Fixed crash when working directory isn’t defined.
  * Fixed stuck game importing due to failure to load icons.
  * Fixed library loading issues on Gentoo.
  * Fixed wine sandboxing on non-english systems.
  * Fixed various issues with locales.
  * Made various changes and improvements for libretro runner.
  * Made various changes and improvements for future Flatpak support.
  * Made minor changes to wording in UI.
  * Updated Zdoom icon
  * Updated Lutris logo (improvements by @Scout339)
* Mon Jul  1 2019 mvetter@suse.com
- Update to 0.5.2.2:
  * Fix installation of Wine Steam runner
  * Restore and preserve original d3d .dll files when DXVK option is not active
* Fri May 24 2019 mvetter@suse.com
- Add python3-evdev for controller support
* Wed Apr 10 2019 mvetter@suse.com
- Update to 0.5.2.1:
  * Handle distributions where ldconfig is not in $PATH, like Debian
  * Fix a crash when GOG credential have changed
  * Leave "Show logs" button always enabled
  * Add BlastEm to libretro cores
* Tue Apr  9 2019 mvetter@suse.com
- Update to 0.5.2:
  * Avoid a crash if the lutris config file is corrupted
  * Install Asian fonts by default on Wine prefix creation
  * Add Vulkan ICD loaders in system options
  * Add SampleCount option to Wine (allows enabling antialiasing in old games)
  * Replace joystick panel with Wine config panel (which contains the joypad panel)
  * Display warning when installing games on NTFS drives
  * Display warning if Vulkan is not fully installed
  * Use ldconfig to determine library paths
  * Disable steamwebhelper in Wine Steam to prevent spamming logs with errors
  * Various bug fixes
* Tue Mar 26 2019 mvetter@suse.com
- Update to 0.5.1.2:
  * Fix issue with custom Proton detection preventing Wine games from running
* Mon Mar 25 2019 mvetter@suse.com
- Update to 0.5.1.1:
  * Cleanup
- Changelog from 0.5.0.1:
  * Download the default Lutris Wine version when not available
  * Prevent duplicates when importing games from 3rd party services
  * Fix some sorting issues in the view
  * Add issue reporting feature with the --submit-issue flag. The issue can
    only be saved locally, API integration will be implemented at a later stage.
  * Add support for CD-ROM images for non CD32/CDTV Amiga models
  * Remove website search from sidebar and merge it with the main search entry
  * Display a warning message if the installed Nvidia driver is too old
  * Fix GOG games not being installable without being connected to GOG
  * Improve performance of log handling
  * Remove winecfg if Proton is used
  * Use discrete graphics by default with compatible systems
  * Increase game icon size from 32x32 to 128x128
  * Various fixes
* Wed Feb 27 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Use automatic runtime dependencies for typelib-*:
  + Add gobject-introspection BuildRequires: enable the feature to
    inspect the code.
  + Drop typelib-1_0-GnomeDesktop-3_0, typelib-1_0-Gtk-3_0,
    typelib-1_0-Notify-0_7 and typelib-1_0-WebKit2-4_0 requires:
    they are now, amongst a couple others, automatically added.
* Tue Feb 26 2019 Yunhe Guo <i@guoyunhe.me>
- Add typelib-1_0-GnomeDesktop-3_0 dependency
* Tue Feb  5 2019 mvetter@suse.com
- Update to 0.5.0.1:
  * Bullshit my way out of Gtk+ fuckery (Closes #1697)
  * Initialize playtime attribute when invalid playtime found (Closes #1698)
  * Strip equal signs from envvars (Closes #1699)
  * Add application attribute on GenericPanel (Closes #1702)
  * Avoid crashing on weird GPU configs (Closes #1706)
  * Remove get_config_id (Closes #1708)
- Changees for 0.5.0:
  * Modernize the Gtk UI, thanks to the improvements made by @TingPing
  * Add GOG support, allowing users to sign-in their account, import games and
    download game files automatically during install.
  * Add finer game import options, allowing imports from different 3rd party
    such as Steam, GOG and locally installed games.
  * Re-architecture the process monitor. This fixes issues with games exiting
    prematurely. Many thanks to @AaronOpfer for his patches!
  * Multiple games can now be launched at the same time without losing control
    over the first game.
  * Game information and actions are now displayed in a panel on the right side.
  * Coverart fetching for the panel will be added in a future release, until then
    cover art files can be placed in ~/.local/share/lutris/coverart/[game-identifier].jpg
  * Games from lutris.net can be searched and installed from the client itself.
  * New install_cab_component installer command for Media Foundation based games.
  * Add a download cache to re-use files between installations.
  * Print graphics drivers and GPU on startup
  * Re-design installer selection picker.
  * Add a button to show installer scripts before installing.
  * Add a FPS limiter option when libstrangle is available (https://gitlab.com/torkel104/libstrangle)
  * Re-architecturing of several parts of the application (views, linux
    feature detection, main game class, ...)
- Guard update desktop file
- Add missing dependencies (boo#1124225)
* Fri Nov  9 2018 Antonio Larrosa <alarrosa@suse.com>
- Add %%doc and %%license files to the package
* Thu Nov  8 2018 Jan Engelhardt <jengelh@inai.de>
- Adjust summary and description grammar.
* Thu Nov  8 2018 mvetter@suse.com
- Add lutris.rpmlintrc as source in spec file
* Wed Nov  7 2018 mvetter@suse.com
- Update to 0.4.23:
  * Prevent monitor from quitting games that open a 2nd process
  * Run on-demand scripts from game directory
  * Tell the user what executable is expected after a failed install
  * Fix a circular import causing issues on some distributions
  * Add missing dependency for openSUSE Tumbleweed
- Remove lutris-0.4.22-imports.patch: upstreamed
* Wed Nov  7 2018 mvetter@suse.com
- Add lutris-0.4.22-imports.patch: Fixes the build
  See: upstream commit a048aba66051a64632904ce9f77feecd076adcf2
* Mon Nov  5 2018 mvetter@suse.com
- Update to 0.4.22:
  * Use lspci instead of xrandr to detect video cards
  * Detect if Vulkan is supported by the system for DXVK games
  * Add experimental playtime support
  * Detect Proton and add it to Wine versions
  * Fix runtime being downloaded when not needed
  * Add experimental tray icon with last games played
  * Add support for Feral Gamemode
  * Prevent process monitor to quit games prematurely
  * Code cleanup
* Wed Oct 24 2018 mvetter@suse.com
- Update to 0.4.21.1:
  * Fix detection of libvulkan
* Mon Oct 22 2018 mvetter@suse.com
- Update to 0.4.21:
  * Added an Esync toggle for wine builds with esync patches and a check for limits if the toggle was activated.
  * Added a warning for wine games if wine is not installed on the system (to avoid issues with dependencies).
  * Added a check for Vulkan loaders when using DXVK (forbids from launching the game if it can't detect them)
  * Added check for the presence of executable after the installation finished.
  * Added an option to sort installed games first
  * Added a discouraging warning if Lutris was launched as root.
  * Added a "--version" command line option.
  * Added an error message if requested DXVK version does not exist.
  * Improved behavior of Lutris' background process.
  * Improved UI when changing game's identifier.
  * Wine's own Virtual Desktop configuration is now respected.
  * Merge command now has a 'copy' alias.
  * Executable selection how has a text field.
  * Blacklisted Proton and SteamWorks from showing up as games.
  * Sidebar now shows number of installed games per runner and platform.
  * Visual improvements to wine download dialog
  * Fixed an issue when DXVK versions didn't get updated if dxvk directory wasn't present.
  * Fixed an issue when the watcher would sync Steam games even if the feature was disabled.
  * Fixed missing warning for existing prefix during installation process if the path contained "~".
  * Prevent Steam games from being synced from the AppManifest watcher if Steam sync if off
  * Games load properly when launching Lutris for the first time
  * Minor improvements to wording in some menus.
* Wed Sep 26 2018 Michael Vetter <mvetter@suse.com>
- Update to 0.4.20:
  * Fix detection of winetricks path
  * Improve visual feedback on wine download dialog
  * Add skill and command-line arguments for Zdoom
  * Add option to disable joypad auto-configuration
  * Restore refresh rate on monitor reset
* Fri Sep  7 2018 mvetter@suse.com
- Update to 0.4.19:
  * Prioritize winetricks from the runtime
  * Populate DXVK versions with github releases
  * Add support for DirectX 10 with DXVK
  * Fix detection of xgamma
  * Add 24BPP option for Xephyr
  * Restore Alsa option for Wine
  * Prepend additional system paths to runtime
* Fri Jun 22 2018 maxmitschke@fastmail.com
- Added python3-gobject-Gdk
- Update to 0.4.18
  * Add custom-name directive for install scripts
  * Add DVXK version option
  * Add more platforms to Mednafen
  * Add new libretro cores
  * Add option for menu mode key in MESS
  * Add option to enable xinput9_1_0.dll in x360ce
  * Add option to include and exclude processes from monitoring in installers
    and during gameplay.
  * Add option to run DRM free Steam games without opening Steam
  * Add RPCS3 runner
  * Add support for 64bit dinput8.dll for x360ce
  * Add support for dumbxinputemu as a x360ce alternative
  * Add support for DXVK in Wine games
  * Add system option to enable DRI_PRIME
  * Add winekill installer task
  * Avoid crash when wine prefix has broken symlinks
  * Better controller support for Mednafen
  * Default 'reset_desktop' option to False
  * Deprecate koku-xinput option
  * Disable Lutris runtime on Wine games if Wine is installed globally
  * Download recent wine version if the system installed one is too old
  * Fix crash on InstallerWindow for GTK < 3.22
  * Fix crash preventing running or configuring wine games
  * Fixes in Wine registry handling
  * Fix 'execute' command arguments
  * Fix lutris eating 100%% CPU after game quits
  * Fix some external library folders not being detected
  * Fix Steam being shut down regardless of the associated option's setting
  * Fix the way wine games quit
  * Fix Wine Steam being killed on game exit even if the option is disabled
  * Fix 'write_json' command when no file exists
  * Fix xboxdrv not being monitored properly
  * Fix xrandr parsing when DisplayPort are available
  * Get pids used by wineserver (experimental, likely to be removed)
  * Make calling executables more robust
  * Prevent Lutris from killing Steam if it's downloading a game
  * Prioritize libraries in /usr/lib over the Lutris runtime
  * Prioritize /usr/lib32 over Lutris runtime
  * Record installation date of games
  * Re-enable Lutris runtime if using a Lutris Wine build
  * Remove Ctrl+Q shortcut
  * Set default Wine architecture to 64bit
  * Stop process monitoring as soon as process stops
  * Support hard disk images for FS-UAE
  * Update DXVK latest version to 0.52
  * Update winetricks
  * Various UI fixes
* Fri Jul 21 2017 mvetter@suse.com
- Remove glib2 dependency
* Sun Jul 16 2017 mvetter@suse.com
- Update to 0.4.12
* Sun Jan 29 2017 mailaender@opensuse.org
- Add gsettings_schemas macros
* Tue Nov 29 2016 strycore@gmail.com
- Ensure correct Python3 dependencies
- Set up Python macros for building
  (Thanks to Pharaoh_Atem on #opensuse-buildservice)
* Sat Oct 15 2016 strycore@gmail.com
- Update to Python 3
- Bump version to 0.4.0
* Sat Dec 12 2015 akien@mageia.org
- Remove ownership of system directories
- Spec file cleanup
* Fri Nov 27 2015 strycore@gmail.com
- Bump to version 0.3.7
* Thu Oct 30 2014 strycore@gmail.com
- Bump to version 0.3.6
- Add OpenSuse compatibility (contribution by @malkavi)
* Fri Sep 12 2014 strycore@gmail.com
- Bump version to 0.3.5
* Thu Aug 14 2014 nickles.travis@gmail.com
- Edited Requires to include pygobject3.
* Wed Jun  4 2014 nickles.travis@gmail.com
- Changed build and install step based on template generated by
  rpmdev-newspec.
- Added Requires.
- Ensure package can be built using mock.
* Tue Jun  3 2014 nickles.travis@gmail.com
- Initial version of the package
